#!/bin/bash

# Copyright (C) since 2006 NTT DATA Corporation
# 
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

# bash configuration
SCRIPT_DIR=$(cd $(dirname $0);pwd)
. ${SCRIPT_DIR}/../../hinemos.cfg
. ${SCRIPT_DIR}/../hinemos_utility.sh

DIR=`dirname $0`
USER=`/usr/bin/whoami`
HOST=`hostname`

########################################
#  Local Variable
########################################
DBPORT=24001
DBNAME=hinemos
DBUSER=hinemos

DUMP_PATH="."
PGDUMP_FILE_BASE="hinemos_pgdump"

DATE=`date "+%Y-%m-%d_%H%M%S"`

SCHEMAS=""
COMP=0
LEVEL=4

########################################
#  Local Message
########################################

# INFO
MSG_I001="dumping data stored in Hinemos RDBMS Server (PostgreSQL)..."
MSG_I002="   output file : "
MSG_I101="successful in dumping data."

# WARN
MSG_W001="output file already exists. remove it and try again."
MSG_W002="this backup file is only for analysis use. Do not restore it!"

# ERROR
MSG_E001="failed to execute pg_dump command."
MSG_E002="failed to dump data."

########################################
# Function
########################################

#
# show usage
#
function usage {
	echo "Usage :"
	echo "        ${PROG} [-w password] [-s]"
	echo "        ${PROG} [-w password] [-d]"
	echo "Options:"
	echo "  -w password  set password (for Hinemos RDBM Server)"
	echo "  -s           backup only setting schema and binarydata schema"
	echo "  -d           backup only setting schema for analysis use (not for restore)"
	echo "  -c level     compress dump file on the specified level 0..9"
}

#
# dump data of PostgreSQL
#
function dump_postgresql {
	AskPostgreSQLPasswd

	FILE_NAME="${PGDUMP_FILE_BASE}${SUFFIX}.${DATE}"
	DUMP_FILE="${DUMP_PATH}/${FILE_NAME}"

    if [ ${COMP} -eq 1 ]
	then
		DUMP_FILE="${DUMP_FILE}.gz"
	fi

	Logging "${MSG_I001}"
	Logging "${MSG_I002}`pwd`/${FILE_NAME}"

	if [ -e ${DUMP_FILE} ]
	then
		Logging "${MSG_W001}"
		return 4
	fi

	PG_DUMP="${PG_HOME}/bin/pg_dump -U ${DBUSER} -p ${DBPORT} ${DBNAME} -f ${DUMP_FILE} "
	if [ "x" != "x${SCHEMAS}" ]
	then
		local ORGIFS="$IFS"
		IFS=','
		local SCHEMA_ARY=($SCHEMAS);
		IFS="$ORGIFS"

		for SCHEMA_NAME in ${SCHEMA_ARY[@]}; do
			PG_DUMP="${PG_DUMP} -n ${SCHEMA_NAME}"
		done
	fi
	if [ ${COMP} -ne 0 ]
	then
		echo "compressing dump file.(level=${LEVEL})"
		PG_DUMP="${PG_DUMP} -Z ${LEVEL} "
	fi
	MSG=`${PG_DUMP} 2>&1`

	RET=$?
	if [ ${RET} -ne 0 ]
	then
		Logging "${MSG}"
		Logging "${MSG_E001}"
		RET=$((16 + ${RET}))
		return ${RET}
	fi
	
	return 0
}

########################################
# SHELL
########################################

# check parameters
for OPT in $@
do
	case $OPT in
		--help|-h)
			usage
			exit 0
			;;
	esac
done

# option check
while getopts sdw:c: OPT
do
	case $OPT in
		w)
			export PGPASSWORD=${OPTARG}
			;;
		s)
			SUFFIX="_s"
			SCHEMAS=setting,binarydata
			;;
		d)
			SUFFIX="_analysisdata"
			SCHEMAS=setting
			Logging "${MSG_W002}"
			;;
		c)
			COMP=1
			LEVEL=${OPTARG}
			;;
		*)
			ExitIllegalOptionErrorWithoutLogger
			;;
	esac
done

shift $(( $OPTIND - 1 ))

if [ ! $# = 0 ]
then
	ExitIllegalArgumentError
fi

# check user
CheckUser ${JVM_USER}

# check process
CheckPostgreSQLProcessRunning

# main
dump_postgresql
RET=$?
if [ ${RET} -ne 0 ]
then
	Logging "${MSG_E002}"
	exit ${RET}
fi

########################################
# Termination Processing
########################################

Logging "${MSG_I101}"
exit ${RET}
