#!/bin/bash

# Copyright (C) since 2006 NTT DATA Corporation
# 
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

# bash configuration
SCRIPT_DIR=$(cd $(dirname $0);pwd)
. ${SCRIPT_DIR}/../../hinemos.cfg
. ${SCRIPT_DIR}/../hinemos_utility.sh

DIR=`dirname $0`
USER=`/usr/bin/whoami`
HOST=`hostname`

export JAVA_OPTS="-Xms16m -Xmx32m"

# for twiddle.log
cd ${HINEMOS_HOME}/var/log

########################################
#  Local Variable
########################################
JMX_HOST=${JMX_HOST:-127.0.0.1}
JMX_PORT=${JMX_PORT:-7100}
JMX_USER=
JMX_PASS=

########################################
#  Local Message
########################################

# INFO
MSG_I001="resetting notification counter..."
MSG_I101="successful in reset notification counter."

# WARN
#MSG_W001=""

# ERROR
MSG_E001="failed to execute CLI."
MSG_E002="failed to reset notification counter."

########################################
# Function
########################################

#
# show usage
#
function usage {
	cat <<EOF
Usage : ${PROG} [-u USERNAME] [-p PASSWORD]
Options:
	-u USERNAME  specify username for JMX authentication
	-p PASSWORD  specify password for JMX authentication

EOF
}

#
# show status
#
function reset_notification_counter {
	Logging "${MSG_I001}"

	CLI_CMD=${HINEMOS_HOME}/sbin/manager_cli

	if [ x${JMX_HOST} != x ];then
		CLI_CMD="${CLI_CMD} -H ${JMX_HOST}"
	fi
	if [ x${JMX_PORT} != x ];then
		CLI_CMD="${CLI_CMD} -P ${JMX_PORT}"
	fi
	if [ x${JMX_USER} != x ];then
		CLI_CMD="${CLI_CMD} -u ${JMX_USER}"
	fi
	if [ x${JMX_PASS} != x ];then
		CLI_CMD="${CLI_CMD} -p ${JMX_PASS}"
	fi

	${CLI_CMD} -o resetNotificationLogger > /dev/null
	RET=$?
	if [ ${RET} -ne 0 ]
	then
		Logging "${MSG_E001}"
		RET=$((16 + ${RET}))
		return ${RET}
	fi

	return 0
}


########################################
# SHELL
########################################

# check parameters
for OPT in $@; do
	case $OPT in
		--help)
			usage
			exit 0
			;;
	esac
done

# check options
while getopts ":u:p:h" OPT; do
	case $OPT in
		u)
			JMX_USER=${OPTARG}
			;;
		p)
			JMX_PASS=${OPTARG}
			;;
		h)
			usage
			exit 0
			;;
	esac
done

shift $(( $OPTIND - 1 ))

if [ ! $# = 0 ]
then
	ExitIllegalArgumentError
fi

# check user
CheckUser ${JVM_USER}

# check process
CheckJVMProcessRunning

# main
if [ ! $# = 0 ]
then
	ExitIllegalArgumentError
fi

reset_notification_counter
RET=$?
if [ ${RET} -ne 0 ]
then
	Logging "${MSG_E002}"

	exit ${RET}
fi

########################################
# Termination Processing
########################################

Logging "${MSG_I101}"
exit 0
