#!/bin/bash

function log()
{
	echo $@ >> ~/install.log.hinemos_manager
}

function log_n()
{
	echo -n $@ >> ~/install.log.hinemos_manager
}

function log_un()
{
	echo $@ >> ~/uninstall.log.hinemos_manager
}

function echo_ok()
{
	log " [OK]"
}

function echo_ng()
{
	log " [NG]"
}

function echo_msg()
{
	local PARAM=$1
	
	if [ -e ${HINEMOS_HOME}/sbin/lib/${LANGUAGE}_install.lng ]
	then
		. ${HINEMOS_HOME}/sbin/lib/${LANGUAGE}_install.lng
	fi
	
	eval 'log "${'${PARAM}'}"'
}

function echo_msg_n(){
	local PARAM=$1
	if [ -e ${HINEMOS_HOME}/sbin/lib/${LANGUAGE}_install.lng ]
	then
		. ${HINEMOS_HOME}/sbin/lib/${LANGUAGE}_install.lng
	fi

	eval 'log_n "${'${PARAM}'}"'
}

function configure_files()
{
	log 
	echo_msg_n MSG_I014
	if [ "$LANGUAGE" = "jp" ]
	then
		locale="ja_JP.UTF-8"
	else
		locale="en_US.UTF-8"
	fi
	
	# create etc folder
	cp -pr ${HINEMOS_ETC_DIR}.template ${HINEMOS_ETC_DIR}
	
	# configure hinemos.cfg
	sed -i -e "s|%%HINEMOS_HOME%%|${HINEMOS_HOME}|" \
		-e "s|%%HINEMOS_ETC_DIR%%|${HINEMOS_ETC_DIR}|" \
		-e "s|%%HINEMOS_LOG_DIR%%|${HINEMOS_LOG_DIR}|" \
		-e "s|%%JAVA_HOME%%|${JAVA_HOME}|" \
		-e "s|%%JAVA_SDK_HOME%%|${JAVA_SDK_HOME}|" \
		-e "s|%%PG_HOME%%|${PG_HOME}|" \
		-e "s|%%PG_DATA%%|${PG_DATA}|" \
		-e "s|%%HINEMOS_OS_USER%%|${HINEMOS_OS_USER}|" \
		-e "s|%%LOCALE%%|${locale}|" \
		${HINEMOS_ETC_DIR}/hinemos.cfg
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E004
		return 255
	fi
	
	# configure postgresql.conf
	sed -i -e "s|%%HINEMOS_LOG_DIR%%|${HINEMOS_LOG_DIR}|" \
		${HINEMOS_ETC_DIR}/postgresql/postgresql.conf
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E004
		return 255
	fi
	
	# configure persistence.xml
	sed -i -e "s|%%HINEMOS_HOME%%|${HINEMOS_HOME}|" \
		${HINEMOS_ETC_DIR}/META-INF/persistence.xml
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E004
		return 255
	fi
	
	# configure snmpd.conf
	if [ -e /etc/snmp/snmpd.conf ] && [ `grep -E "^view.+systemview.+included.+.1\.3\.6\.1$" /etc/snmp/snmpd.conf | wc -l` -eq 0 ]
	then
		log 
		echo_msg MSG_I042
		cp -pr /etc/snmp/snmpd.conf /etc/snmp/snmpd.conf.saved_`date +"%Y%m%d-%H%M%S"`
		echo "view	systemview	included   .1.3.6.1" >> /etc/snmp/snmpd.conf
		
		# configure runlevel and restart snmpd
		service snmpd status > /dev/null 2>&1 && service snmpd stop
		chkconfig --level 2345 snmpd on && service snmpd start
		if [ $? -ne 0 ]
		then
			echo_ng
		fi
		
		echo_msg MSG_I043
		echo_msg MSG_I044
		echo_msg MSG_W008
	else
		echo_msg MSG_I045
	fi
	echo_ok
	
	return 0
}

function configure_rsyslog() {
	log
	echo_msg_n MSG_I057
	RSYSLOG_AGENT_CONF=/etc/rsyslog.d/rsyslog_hinemos_agent.conf
	if [ -e ${RSYSLOG_AGENT_CONF} ]
	then
		AGENT_BKUP=${RSYSLOG_AGENT_CONF}.saved_`date +"%Y%m%d-%H%M%S"`
	mv $RSYSLOG_AGENT_CONF $AGENT_BKUP
	fi
	cp -p ${HINEMOS_HOME}/etc.template/rsyslog_hinemos_manager.conf /etc/rsyslog.d/
	service rsyslog restart
	if [ $? -ne 0 ]
	then
		echo_ng
	fi
			
	return 0
}

function input_mount_point()
{
	log
	echo_msg MSG_I039
	FILESYSTEMS=`df -P | grep "^/dev" | awk '{ print $1}'`
	for FILESYSTEM in ${FILESYSTEMS}
	do
		MOUNTPOINT=`df -P | grep "^${FILESYSTEM}" | awk '{print $6}'`
		if [ "x${FILESYSTEM}" != "x" ] && [ "x${MOUNTPOINT}" != "x" ]
		then
			log "   ${FILESYSTEM} - ${MOUNTPOINT}"
		fi
	done
	
	MOUNTPOINT_DB="/"
	DIR=${PG_DATA}
	while [ "x${DIR}" != "x/" ] || [ "x${DIR}" != "x." ]
	do
		if [ `df -P | awk '{print $6}' | grep "^${DIR}$" | wc -l` -gt 0 ]
		then
			MOUNTPOINT_DB=${DIR}
			echo_msg MSG_I040
			break
		fi
		DIR=`dirname ${DIR}`
	done
	
	MOUNTPOINT_LOG="/"
	DIR=${HINEMOS_LOG_DIR}
	while [ "x${DIR}" != "x/" ] || [ "x${DIR}" != "x." ]
	do
		if [ `df -P | awk '{print $6}' | grep "^${DIR}$" | wc -l` -gt 0 ]
		then
			MOUNTPOINT_LOG=${DIR}
			echo_msg MSG_I041
			break
		fi
		DIR=`dirname ${DIR}`
	done
	
	return 0
}

function change_owner()
{
	log
	echo_msg_n MSG_I016
	chown -R ${HINEMOS_OS_USER}:${HINEMOS_OS_USER} ${HINEMOS_HOME} \
		&& chown root:root ${HINEMOS_HOME}/sbin/fping \
		&& chmod 4755 ${HINEMOS_HOME}/sbin/fping \
		&& chown root:root ${HINEMOS_HOME}/sbin/fping6 \
		&& chmod 4755 $HINEMOS_HOME/sbin/fping6
	if [ $? -ne 0 ]
	then
		echo_ng
		echo_msg MSG_E004
		return 255
	fi
	echo_ok
	return 0
}

function initialize_database()
{
	log
	echo_msg MSG_I029

	su -c "${HINEMOS_HOME}/sbin/db_init/pg_init.sh ${LANGUAGE}" - ${HINEMOS_OS_USER} >> ~/install.log.hinemos_manager 2>&1
	if [ $? -ne 0 ]
	then
		echo_msg MSG_E012 && echo_msg MSG_E004
		return 255
	fi
	
	return 0
}

function remove_rsyslog_manager_conf()
{
	RSYSLOG_MANAGER_CONF=/etc/rsyslog.d/rsyslog_hinemos_manager.conf
	MANAGER_BKUP=${RSYSLOG_MANAGER_CONF}.saved_`date +"%Y%m%d-%H%M%S"`
	mv $RSYSLOG_MANAGER_CONF $MANAGER_BKUP

	service rsyslog status
	if [ $? -eq 0 ]
	then
		service rsyslog restart
	fi

	return 0
}

function configure_hinemos_manager_service()
{
	#hinemos manager
	chkconfig --add hinemos_manager
}


function remove_hinemos_manager_service()
{
	/etc/init.d/hinemos_manager stop
	chkconfig --del hinemos_manager 
}