#!/bin/bash
INSTALL_SLEEP=0.2

function log()
{
	echo $@ >> ~/install.log.hinemos_agent
}

function log_un()
{
	echo $@ >> ~/uninstall.log.hinemos_agent
}

function echo_ok()
{
	log " [OK]"
}

function echo_ng()
{
	log " [NG]"
}

#configure rsylog
function configure_rsyslog()
{
	if [ ! -e ${RSYSLOG_CONF} ] && [ ! -e ${SYSLOG_CONF} ]
	then
		log "${MSG_I062}"
		return 0
	fi

	rpm -qi hinemos-manager >> ~/install.log.hinemos_agent
	MANAGER_INSTALLED=$?
	if [ -e ${RSYSLOG_CONF} ]
	then
		#manager is installed
		if [ $MANAGER_INSTALLED == 0 ]
		then
			# restart rsyslog
			service rsyslog status >> ~/install.log.hinemos_agent
			if [ $? -ne 0 ]
			then
				log "${MSG_I064}"
			else
				service rsyslog restart
			fi
			return 0
		fi
	
		if [ ! -e $RSYSLOGD ]
		then
			mkdir $RSYSLOGD
			
			grep "^\$IncludeConfig /etc/rsyslog\.d/\*\.conf" $RSYSLOG_CONF > /dev/null
			if [ $? -ne 0 ]
			then
				echo "\$IncludeConfig /etc/rsyslog.d/*.conf" >> $RSYSLOG_CONF
			fi
		fi
	
		sleep ${INSTALL_SLEEP}
		
		if [ "${MANAGER_IP_ADDRESS}" != "127.0.0.1" ]
		then
			RSYSLOG_AGENT_CONF=/etc/rsyslog.d/rsyslog_hinemos_agent.conf
		else
			RSYSLOG_AGENT_CONF=/etc/rsyslog.d/rsyslog_hinemos_agent.conf.saved_`date +"%Y%m%d-%H%M%S"`
		fi

		# copy rsyslog_hinemos_agent.conf
		cp ${HINEMOS_AGENT_HOME}/conf.template/rsyslog_hinemos_agent.conf ${RSYSLOG_AGENT_CONF}

		#configure rsyslog_hinemos_agent.conf
		sed -i -e "s|%%MANAGER_IP_ADDRESS%%|${MANAGER_IP_ADDRESS}|" \
			-e "s/%%ID%%/${ID}/" \
			${RSYSLOG_AGENT_CONF}		

		# restart rsyslog
		service rsyslog status >> ~/install.log.hinemos_agent
		if [ $? -ne 0 ]
		then
			log "${MSG_I064}"
		else
			service rsyslog restart
		fi
	else
		#syslog.conf
		#manager not installed
		if [ $MANAGER_INSTALLED -ne 0 ]
		then
			if [ "${MANAGER_IP_ADDRESS}" != "127.0.0.1" ]
			then
				cat >> $SYSLOG_CONF << EOS
#
# Hinemos Agent ${VERSION} (for syslog monitoring)
#
*.info;mail.none;authpriv.none;cron.none		@${MANAGER_IP_ADDRESS}:514
EOS

			fi
		fi
		
		# restart syslog
		service syslog status >> ~/install.log.hinemos_agent
		if [ $? -ne 0 ]
		then
			log "${MSG_I066}"
		else
			service syslog restart
		fi		
	fi
	
	
	return 0
}

function configure_files()
{
	log
	log "${MSG_I021}" && sleep ${INSTALL_SLEEP}
	
	if [ "$LANGUAGE" = "" ]
	then
		locale="$LANG"
	else
		if [ "$LANGUAGE" = "jp" ]
		then
			locale="ja_JP.UTF-8"
		else
			locale="en_US.UTF-8"
		fi
	fi

	# create conf folder
	cp -pr ${HINEMOS_AGENT_HOME}/conf.template ${HINEMOS_AGENT_HOME}/conf

	# configure hinemos.cfg
	sed -i -e "s|%%HINEMOS_AGENT_HOME%%|${HINEMOS_AGENT_HOME}|" \
		-e "s/%%ID%%/${ID}/" \
		-e "s/%%LOCALE%%/${locale}/" \
		${HINEMOS_AGENT_HOME}/conf/hinemos_agent.cfg

	if [ $? -ne 0 ]
	then
		echo_ng
		log "${MSG_E004}"
		return 25
	fi
		
	# edit JAVA_HOME
	log ""
	log "${MSG_I057}"
	log "----------"
	log `${JAVA_DIR_OSORIGINAL}/bin/java -version 2>&1`
	log "----------"
	log "${MSG_I058}"
	sed -i -e "s|${HINEMOS_AGENT_HOME}/%%JAVA_DIR%%|${JAVA_DIR_OSORIGINAL}|" \
		${HINEMOS_AGENT_HOME}/conf/hinemos_agent.cfg
	RET=$?
	if [ ${RET} -ne 0 ]
	then
		echo_ng
		log "${MSG_E004}"
		return 26
	fi
	
	# configure Agent
	sed -i -e "s/%%MANAGER_IP_ADDRESS%%/${MANAGER_IP_ADDRESS}/" \
		${HINEMOS_AGENT_HOME}/conf/Agent.properties

	if [ $? -ne 0 ]
	then
		echo_ng
		log "${MSG_E004}"
		return 27
	fi

	# configure agent_start.sh
	sed -e "s/%%JAVA_CHECK_REGEX%%/${JAVA_CHECK_REGEX}/" \
		-e "s/%%OPENJDK_CHECK_REGEX%%/${OPENJDK_CHECK_REGEX}/" \
		${HINEMOS_AGENT_HOME}/bin/agent_start.sh.template > \
		${HINEMOS_AGENT_HOME}/bin/agent_start.sh && \
		chmod 755 ${HINEMOS_AGENT_HOME}/bin/agent_start.sh

	if [ $? -ne 0 ]
	then
		echo_ng
		log "${MSG_E004}"
		return 255
	fi
	
	echo_ok
	
	log ""
	log "${MSG_I071}" && echo_ok
		
	return 0
}

function configure_net_snmp()
{	
	# configure snmpd.conf
	if [ -e ${SNMP_CONF} ] && [ `grep -E "^view.+systemview.+included.+.1\.3\.6\.1$" ${SNMP_CONF} | wc -l` -eq 0 ]
	then
		echo
		log -n "${MSG_I023}" && sleep ${INSTALL_SLEEP}
		cp -pr ${SNMP_CONF} ${SNMP_CONF}.saved_`date +"%Y%m%d-%H%M%S"`
		echo "view	systemview	included   .1.3.6.1" >> ${SNMP_CONF}
		echo "# disk / 10000" >> ${SNMP_CONF}
		echo "# disk /var 10000" >> ${SNMP_CONF}
		
		# configure runlevel and restart snmpd
		service snmpd status > /dev/null 2>&1 && service snmpd stop
		chkconfig --level 2345 snmpd on && service snmpd start
		if [ $? -ne 0 ]
		then
			echo_ng
			log "${MSG_E004}"
			return 31
		fi
		
		log "${MSG_I024} (appended \"view systemview included .1.3.6.1\")"
		log "${MSG_I043}"
		log "${MSG_W014}"
	else
		log "${MSG_I025}"
	fi
	
	return 0
}

function configure_hinemos_agent_service()
{
	#hinemos agent
	chkconfig --add hinemos_agent
}

function remove_rsyslog_agent_conf()
{
	RSYSLOG_AGENT_CONF=/etc/rsyslog.d/rsyslog_hinemos_agent.conf
	if [ -e $RSYSLOG_AGENT_CONF ]
	then
		AGENT_BKUP=${RSYSLOG_AGENT_CONF}.saved_`date +"%Y%m%d-%H%M%S"`
		mv $RSYSLOG_AGENT_CONF $AGENT_BKUP
	
		service rsyslog status
		if [ $? -eq 0 ]
		then
		service rsyslog restart
		fi
	fi

	return 0
}

function remove_hinemos_agent_service()
{
	/etc/init.d/hinemos_agent stop
	chkconfig --del hinemos_agent 
}
